<?php
/**
 * Customizer active callbacks
 *
 * @package Theme Palace
 * @subpackage Daily Insight Pro
 * @since Daily Insight Pro 1.0
 */

if ( ! function_exists( 'daily_insight_pro_is_loader_enable' ) ) :
	/**
	 * Check if loader is enabled.
	 *
	 * @since Daily Insight Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_loader_enable( $control ) {
		return $control->manager->get_setting( 'daily_insight_pro_theme_options[loader_enable]' )->value();
	}
endif;

if ( ! function_exists( 'daily_insight_pro_is_breadcrumb_enable' ) ) :
	/**
	 * Check if breadcrumb is enabled.
	 *
	 * @since Daily Insight Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_breadcrumb_enable( $control ) {
		return $control->manager->get_setting( 'daily_insight_pro_theme_options[breadcrumb_enable]' )->value();
	}
endif;

if ( ! function_exists( 'daily_insight_pro_is_pagination_enable' ) ) :
	/**
	 * Check if pagination is enabled.
	 *
	 * @since Daily Insight Pro 1.0
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_pagination_enable( $control ) {
		return $control->manager->get_setting( 'daily_insight_pro_theme_options[pagination_enable]' )->value();
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_breaking_news_active' ) ) :
	/**
	 * Check if Breaking News is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_breaking_news_active( $control ) {

		return $control->manager->get_setting( 'daily_insight_pro_theme_options[enable_breaking_news]' )->value();
	}
endif;

if ( ! function_exists( 'daily_insight_pro_is_breaking_news_category_type_active' ) ) :
	/**
	 * Check if Breaking News category type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_breaking_news_category_type_active( $control ) {
		if ( ( daily_insight_pro_is_breaking_news_active( $control ) ) && ( 'category' == $control->manager->get_setting( 'daily_insight_pro_theme_options[breaking_news_type]' )->value() ) )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_latest_post_active' ) ) :
	/**
	 * Check if Latest Post is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_latest_post_active( $control ) {

		return ( 'static-frontpage' == $control->manager->get_setting( 'daily_insight_pro_theme_options[enable_latest_post]' )->value() );
	}
endif;

if ( ! function_exists( 'daily_insight_pro_is_latest_post_recent_active' ) ) :
	/**
	 * Check if Latest Post Select type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_latest_post_recent_active( $control ) {
		if ( ( daily_insight_pro_is_latest_post_active( $control ) ) && ( 'recent-post' == $control->manager->get_setting( 'daily_insight_pro_theme_options[latest_post_type]' )->value() ) )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_main_slider_active' ) ) :
	/**
	 * Check if Main Slider is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_main_slider_active( $control ) {

		return ( 'static-frontpage' == $control->manager->get_setting( 'daily_insight_pro_theme_options[enable_main_slider]' )->value() );
	}
endif;

if ( ! function_exists( 'daily_insight_pro_is_main_slider_demo_not_active' ) ) :
	/**
	 * Check if Main Slider Select type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_main_slider_demo_not_active( $control ) {
		if ( ( daily_insight_pro_is_main_slider_active( $control ) ) && ( 'demo' != $control->manager->get_setting( 'daily_insight_pro_theme_options[main_slider_type]' )->value() ) )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_main_slider_content_as_category' ) ) :
	/**
	 * Check if Main Slider Category type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_main_slider_content_as_category( $control ) {
		if ( ( daily_insight_pro_is_main_slider_active( $control ) ) && ( 'category' == $control->manager->get_setting( 'daily_insight_pro_theme_options[main_slider_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'daily_insight_pro_is_main_slider_content_as_post' ) ) :
	/**
	 * Check if Main Slider Post type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_main_slider_content_as_post( $control ) {
		if ( ( daily_insight_pro_is_main_slider_active( $control ) ) && ( 'post' == $control->manager->get_setting( 'daily_insight_pro_theme_options[main_slider_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'daily_insight_pro_is_main_slider_content_as_page' ) ) :
	/**
	 * Check if Main Slider page type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_main_slider_content_as_page( $control ) {
		if ( ( daily_insight_pro_is_main_slider_active( $control ) ) && ( 'page' == $control->manager->get_setting( 'daily_insight_pro_theme_options[main_slider_type]' )->value() ) )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_primary_menu_enable' ) ) :
	/**
	 * Check if primary menu is enabled.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_primary_menu_enable( $control ) {
		if ( 0 ==  $control->manager->get_setting( 'daily_insight_pro_theme_options[disable_primary_menu]' )->value() ) 
			return true;
		else
			return false;
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_category_block_one_active' ) ) :
	/**
	 * Check if Category Block one is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_one_active( $control ) {

		return $control->manager->get_setting( 'daily_insight_pro_theme_options[enable_category_block_one]' )->value();
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_category_block_one_content_as_category' ) ) :
	/**
	 * Check if Category Block one Category type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_one_content_as_category( $control ) {
		if ( ( daily_insight_pro_is_category_block_one_active( $control ) ) && ( 'category' == $control->manager->get_setting( 'daily_insight_pro_theme_options[category_block_one_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'daily_insight_pro_is_category_block_two_active' ) ) :
	/**
	 * Check if Category Block two is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_two_active( $control ) {

		return $control->manager->get_setting( 'daily_insight_pro_theme_options[enable_category_block_two]' )->value();
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_category_block_two_content_as_category' ) ) :
	/**
	 * Check if Category Block two Category type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_two_content_as_category( $control ) {
		if ( ( daily_insight_pro_is_category_block_two_active( $control ) ) && ( 'category' == $control->manager->get_setting( 'daily_insight_pro_theme_options[category_block_two_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'daily_insight_pro_is_category_block_three_active' ) ) :
	/**
	 * Check if Category Block three is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_three_active( $control ) {

		return $control->manager->get_setting( 'daily_insight_pro_theme_options[enable_category_block_three]' )->value();
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_category_block_three_content_as_category' ) ) :
	/**
	 * Check if Category Block three Category type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_three_content_as_category( $control ) {
		if ( ( daily_insight_pro_is_category_block_three_active( $control ) ) && ( 'category' == $control->manager->get_setting( 'daily_insight_pro_theme_options[category_block_three_type]' )->value() ) )
			return true;

		return false;
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_category_block_four_active' ) ) :
	/**
	 * Check if Category Block four is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_four_active( $control ) {

		return $control->manager->get_setting( 'daily_insight_pro_theme_options[enable_category_block_four]' )->value();
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_category_block_four_content_as_category' ) ) :
	/**
	 * Check if Category Block four Category type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_four_content_as_category( $control ) {
		if ( ( daily_insight_pro_is_category_block_four_active( $control ) ) && ( 'category' == $control->manager->get_setting( 'daily_insight_pro_theme_options[category_block_four_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'daily_insight_pro_is_category_block_five_active' ) ) :
	/**
	 * Check if Category Block five is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_five_active( $control ) {

		return $control->manager->get_setting( 'daily_insight_pro_theme_options[enable_category_block_five]' )->value();
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_category_block_five_content_as_category' ) ) :
	/**
	 * Check if Category Block five Category type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_five_content_as_category( $control ) {
		if ( ( daily_insight_pro_is_category_block_five_active( $control ) ) && ( 'category' == $control->manager->get_setting( 'daily_insight_pro_theme_options[category_block_five_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'daily_insight_pro_is_category_block_six_active' ) ) :
	/**
	 * Check if Category Block six is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_six_active( $control ) {

		return $control->manager->get_setting( 'daily_insight_pro_theme_options[enable_category_block_six]' )->value();
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_category_block_six_content_as_category' ) ) :
	/**
	 * Check if Category Block six Category type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_six_content_as_category( $control ) {
		if ( ( daily_insight_pro_is_category_block_six_active( $control ) ) && ( 'category' == $control->manager->get_setting( 'daily_insight_pro_theme_options[category_block_six_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'daily_insight_pro_is_category_block_seven_active' ) ) :
	/**
	 * Check if Category Block seven is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_seven_active( $control ) {

		return $control->manager->get_setting( 'daily_insight_pro_theme_options[enable_category_block_seven]' )->value();
	}
endif;


if ( ! function_exists( 'daily_insight_pro_is_category_block_seven_content_as_category' ) ) :
	/**
	 * Check if Category Block seven Category type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_seven_content_as_category( $control ) {
		if ( ( daily_insight_pro_is_category_block_seven_active( $control ) ) && ( 'category' == $control->manager->get_setting( 'daily_insight_pro_theme_options[category_block_seven_type]' )->value() ) )
			return true;

		return false;
	}
endif;

if ( ! function_exists( 'daily_insight_pro_is_category_block_seven_demo_type_not_active' ) ) :
	/**
	 * Check if Category Block seven Category type is active.
	 *
	 * @since Daily Insight Pro 1.0
	 *
	 * @param WP_Customize_Control $control WP_Customize_Control instance.
	 *
	 * @return bool Whether the control is active to the current preview.
	 */
	function daily_insight_pro_is_category_block_seven_demo_type_not_active( $control ) {
		if ( ( daily_insight_pro_is_category_block_seven_active( $control ) ) && ( 'demo' != $control->manager->get_setting( 'daily_insight_pro_theme_options[category_block_seven_type]' )->value() ) )
			return true;

		return false;
	}
endif;



